import React, {useContext, useState} from "react";
import {Form, Input, message, Modal, Upload,} from "antd";
import {useStore} from "../../utils/useStore";
import {LoadingOutlined, PlusOutlined} from "@ant-design/icons";
import {ModalLoaderContext} from "../../utils/modal";
import {http} from "../../utils/http";
import {appConfig} from "../../config/app";

export const PaybackModal = ({visible, onCreate, onCancel, initialData}) => {
  const [form] = Form.useForm();
  const store = useStore();
  const [image, setImage] = useState("");
  const [fileList, setFileList] = useState([]);
  const [previewImage, setPreviewImage] = useState("");
  const [previewVisible, setPreviewVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  const modalLoader = useContext(ModalLoaderContext);

  const beforeUpload = (file) => {
    let isLt2M;
    let allowedFile = ["image/jpeg", "image/png"];
    let isValid = allowedFile.includes(file.type);
    if (!isValid) {
      message.error("You can only upload Image file!");
    }
    isLt2M = file.size / 1024 / 1024 < 2;
    if (!isLt2M) {
      message.error("File must smaller than 2MB!");
    }
    return isValid && isLt2M ? true : Upload.LIST_IGNORE;
  };

  const uploadHandler = async (args) => {
    const file = args.file;
    const res = await http.upload(file);
    setImage(`${appConfig.apiUrl}/config/image/${res.body.filename}`);
    setFileList([{
      uid: '-1',
      name: 'image',
      status: 'done',
      url: `${appConfig.apiUrl}/config/image/${res.body.filename}`,
    }]);
  };

  const handleChange = (info) => {
    if (info.file.status === 'uploading') {
      setLoading(true);
      return;
    }
    setLoading(false)
  };

  const uploadButton = (
      <div>
        {loading ? <LoadingOutlined/> : <PlusOutlined/>}
        <div style={{marginTop: 8}}>Click to Upload</div>
      </div>
  );

  const handleSubmit = async (data) => {
    console.log(data, "isi data2");
    try {
      modalLoader.setLoading(true);
      await store.payback.create(data);
      modalLoader.setLoading(false);
      message.success("Success Add Payback");
      await store.payback.getData();
    } catch (e) {
      modalLoader.setLoading(false);
      if (e.response?.body?.message) {
        message.error(e.response.body.message);
        return;
      }
      message.error(e.message);
    }
    form.resetFields();
  };

  return (
      <Modal
          visible={visible}
          title={"Create a new Payback"}
          okText={"Create"}
          cancelText="Cancel"
          onCancel={() => {
            form.resetFields();
            onCancel();
          }}
          onOk={() => {
            form
                .validateFields()
                .then((values) => {
                  handleSubmit(values);
                  console.log(values);
                  form.resetFields();
                })
                .catch((info) => {
                  console.log("Validate Failed:", info);
                });
          }}
      >
        <Form
            form={form}
            layout="vertical"
            name="form_in_modal"
            initialValues={initialData}
        >
          <Form.Item
              name="destination"
              label="destination"
              rules={[{required: true, message: "Please input Name!"}]}
              initialValue={store.authentication.profileData.superior?.id}
          >
            <Input/>
          </Form.Item>
          <Form.Item
              label="Upload Picture"
              name="image_prove"
          >
            <div>
              <Upload
                  listType="picture-card"
                  fileList={fileList}
                  onPreview={(file) => {
                    setPreviewImage(file.url || file.filename);
                    setPreviewVisible(file.url || file.filename);
                  }}
                  showUploadList={true}
                  onChange={handleChange}
                  beforeUpload={(file) => beforeUpload(file)}
                  customRequest={(args) => uploadHandler(args)}
                  onRemove={(file) => {
                    setImage('');
                    setLoading(false);
                    setFileList([]);
                  }}
              >

                {image === "" ? uploadButton : null}
              </Upload>
              <h5
                  style={{
                    marginTop: 12,
                    color: "rgba(0, 0, 0, 0.45)",
                  }}
              >
                Max size of file 2 mb
              </h5>
            </div>
          </Form.Item>
          <Form.Item
              name="amount"
              label="amount"
              rules={[{required: true, message: "Please input Amount!"}]}
          >
            <Input/>
          </Form.Item>
        </Form>
      </Modal>
  );
};
